@@ -343,15 +343,20 @@ def to_date(formatted='%Y-%m-%d'):
 
     """
     def _to_date(self, model, field, value, line):
-        date = value
         try:
             date = str(value.split('\n')[0])
         except:
             pass
-        if date in ('0000-00-00', '0000/00/00', '00-00-0000', '00/00/0000', ''):
-            return ''
-        date = datetime.strptime(date, formatted)
-        return date.strftime('%Y-%m-%d')
+
+        try:
+            date = datetime.strptime(value, formatted)
+            res = date.strftime('%Y-%m-%d')
+        except Exception as err:
+            self._logger.error(u"Datetime malformed (%s)." % err,
+                    extra=STATS[self._id])
+            res = ''
+
+        return res
 
     return _to_date
 
